pub struct Parameter {
pub keyword: &'static str,
pub kind: u16,
pub required: bool,
pub description: &'static str,
pub default: Option<&'static Value>,
pub enum_variants: Option<&'static [EnumVariant]>,
}Fields
keyword: &'static strThe keyword of the parameter.
Arguments can be passed in both using the keyword, or as a positional argument.
kind: u16The type kind(s) this parameter expects to receive.
If an invalid kind is provided, the compiler will return a compile-time error.
required: boolWhether or not this is a required parameter.
If it isn’t, the function can be called without errors, even if the argument matching this parameter is missing.
description: &'static strA description of what this parameter does.
default: Option<&'static Value>The default value for this parameter, if any.
Notes on creating a Option<&'static Value>:
- If the inner
Valueis copiable, such asValue::Integer, you likely won’t have issues. - If the value can contain owned data, such as
Value::Bytes, useLazyLockto create staticValueinstances. If you are already in aLazyLockblock, you’ll have to create anotherLazyLockin order to make both static.
enum_variants: Option<&'static [EnumVariant]>Enum variants for this parameter, if the parameter accepts a limited set of values.
Implementations
Sourceimpl Parameter
impl Parameter
Sourcepub const fn required(
keyword: &'static str,
kind: u16,
description: &'static str,
) -> Self
pub const fn required( keyword: &'static str, kind: u16, description: &'static str, ) -> Self
Create a required parameter with default values for default and enum_variants.
Sourcepub const fn optional(
keyword: &'static str,
kind: u16,
description: &'static str,
) -> Self
pub const fn optional( keyword: &'static str, kind: u16, description: &'static str, ) -> Self
Create an optional parameter with default values for default and enum_variants.
Sourcepub const fn default(self, value: &'static Value) -> Self
pub const fn default(self, value: &'static Value) -> Self
Set the default value for this parameter.
Sourcepub const fn enum_variants(self, variants: &'static [EnumVariant]) -> Self
pub const fn enum_variants(self, variants: &'static [EnumVariant]) -> Self
Set the enum variants for this parameter.
pub fn kind(&self) -> Kind